@@ -8,8 +8,8 @@ comparebcSpec <-function (marker1, marker2, D, atSens, alpha, plots){
     stop("ERROR: The level of significance, alpha, should be set between 0 and 1. A common choice is 0.05.")
   } else if (sum(is.na(marker1)) > 0 | sum(is.na(marker2)) > 0 | sum(is.na(D)) > 0 | sum(is.na(atSens)) > 0) {
     stop("ERROR: Please remove all missing data before running this function.")
-  } else if (!is.numeric(atSens)) {
-    stop("ERROR: 'atSpec' must be a numeric vector.")
+  } else if ((!is.numeric(atSens)) | (length(atSens) != 1)) {
+    stop("ERROR: 'atSens' must be a single numeric value.")
   } else {
 
     erf <- function (x) 2 * pnorm(x * sqrt(2)) - 1
@@ -53,22 +53,28 @@ comparebcSpec <-function (marker1, marker2, D, atSens, alpha, plots){
       na = length(W1alam)
       nb = length(W1blam)
 
+      s1alam=sqrt(var(W1alam)*(na-1)/na)
+      s1blam=sqrt(var(W1blam)*(nb-1)/nb)
+
       1-pnorm(qnorm(1-t,
                     mean=mean(W1blam),
-                    sd=std(W1blam)*((nb-1)/nb)),
+                    sd=s1blam),
               mean=mean(W1alam),
-              sd=std(W1alam)*((na-1)/na))
+              sd=s1alam)
     }
 
     roct2<-function(t){
       na = length(W2alam)
       nb = length(W2blam)
 
+      s2alam=sqrt(var(W2alam)*(na-1)/na)
+      s2blam=sqrt(var(W2blam)*(nb-1)/nb)
+
       1-pnorm(qnorm(1-t,
                     mean=mean(W2blam),
-                    sd=std(W2blam)*((nb-1)/nb)),
+                    sd=s2blam),
               mean=mean(W2alam),
-              sd=std(W2alam)*((na-1)/na))
+              sd=s2alam)
     }
 
     rocuseless<-function(t){
@@ -90,24 +96,28 @@ comparebcSpec <-function (marker1, marker2, D, atSens, alpha, plots){
       #line for the Youden:
       #lines(c(1-atSpec,1-SE1),c(1-atSpec,1-SE2),col="green")
 
-      legend("bottomright", legend=c(paste("ROC for Marker 1 with FPR =", round(FPR1,4), "at Sens =", atSens),
-                                     paste("ROC for Marker 2 with FPR =", round(FPR2,4), "at Sens =", atSens),
-                                     paste("P-value for the Spec difference:",round(pval2t,4))),
+      legend("bottomright", legend=c(paste("ROC for Marker 1 with FPR =", formattable(FPR1, digits = 4, format = "f"), "at Sens =", formattable(atSens, digits = 4, format = "f")),
+                                     paste("ROC for Marker 2 with FPR =", formattable(FPR2, digits = 4, format = "f"), "at Sens =", formattable(atSens, digits = 4, format = "f")),
+                                     paste("P-value for the Spec difference:", formattable(pval2t, digits = 4, format = "f"))),
 
              col=c("red", "black", "white"), lty=c(1, 1, NA), pch = c(NA, NA, NA), cex=0.8)
 
     }
 
-
-    res <- matrix(c(FPR1,FPR2, pval2t, CIZstar[1],CIZstar[2]),ncol=5,byrow=TRUE)
-    colnames(res) <- c("FPR 1:","    FPR 2:","    p-value (probit):","   CI probit (LL):","    CI probit (UL):")
+    res <- data.frame(FPR1 = formattable(FPR1, digits = 4, format = "f"),
+                      FPR2 = formattable(FPR2, digits = 4, format = "f"),
+                      p_value_probit = formattable(pval2t, digits = 4, format = "f"),
+                      p_value = formattable(pval2tZ, digits = 4, format = "f"),
+                      ci_ll = formattable(CIoriginal[1], digits = 4, format = "f"),
+                      ci_ul = formattable(CIoriginal[2], digits = 4, format = "f"))
     rownames(res) <- c("Estimates:")
-    res <- as.table(res)
+    colnames(res) <- c("AUC 1", "AUC 2", "P-Val (Probit)", "P-Val", "CI (LL)", "CI (UL)")
+    res <- formattable(as.matrix(res), digits = 4, format = "f")
     res
 
 
     #return(list(resultstable=res,Sens1=SE1,Sens2=SE2, pvalue_probit_difference= pval2t, CI_probit_difference= CIZstar, pvalue_difference= pval2tZ, CI_difference= CIoriginal, roc1=roc1, roc2=roc2, transx1=W1alam, transy1=W1blam, transx2=W2alam, transy2=W2blam))
-    return(list(resultstable=res,FPR1=FPR1,FPR2=FPR2, pvalue_probit_difference= pval2t, CI_probit_difference= CIZstar, pvalue_difference= pval2tZ, CI_difference= CIoriginal, roc1=roct1, roc2=roct2, transx1=W1alam, transy1=W1blam, transx2=W2alam, transy2=W2blam))
+    return(list(resultstable=res,FPR1=FPR1,FPR2=FPR2, pvalue_probit_difference= pval2t, pvalue_difference= pval2tZ, CI_difference= CIoriginal, roc1=roct1, roc2=roct2, transx1=W1alam, transy1=W1blam, transx2=W2alam, transy2=W2blam))
     #return(list(FPR1=FPR1))
 
 
